==> fillets-ng-data-0.7.1.tar.gz: fillets-ng-data-0.7.1/script/imprisoned/dialogs_nl.lua <==

dialogId("ncp-m-tesno0", "font_small", "Look, how I am supposed to get out of here?")
dialogStr("Kijk nou, hoe moet ik hier nou weer uit zien te komen?")


dialogId("ncp-m-tesno1", "font_small", "It`s quite tight in here.")
dialogStr("Beetje krap hier.")


dialogId("ncp-v-dostala", "font_big", "How did you manage to get there?")
dialogStr("Hoe kom je daar nou weer terecht?")


dialogId("ncp-v-sasanka", "font_big", "Stop playing with anemones and help me to get us out of here.")
dialogStr("Hou op met die anemonen te spelen en help me ons hieruit te krijgen.")


dialogId("ncp-m-nekoukej", "font_small", "Don`t be surprised.")
dialogStr("Schrik niet, zeepaardje.")


dialogId("ncp-m-komari", "font_small", "There are so many corals here...")
dialogStr("Er zijn een hoop zo veel karollen...")


dialogId("ncp-v-ceho", "font_big", "What?")
dialogStr("Wat?")


dialogId("ncp-m-koraly", "font_small", "So many corals. Are you deaf or what?")
dialogStr("Zo veel koralen. Ben je doof ofzo?")


dialogId("ncp-m-tvrdy", "font_small", "Oh my, this is a hard coral.")
dialogStr("O, dit is een hard stuk koraal.")


dialogId("ncp-v-mekky", "font_big", "Oh my, this is a soft coral.")
dialogStr("O jeetje, dit is een zacht stuk koraal.")


dialogId("ncp-v-tak", "font_big", "So!")
dialogStr("Zo!")


dialogId("ncp-m-muzes", "font_small", "Now you can get out, can`t you?")
dialogStr("Nu kun je eruit, of niet?")


dialogId("ncp-v-neprojedu", "font_big", "Hmm, I can`t get through here...")
dialogStr("Hmm, hier pas ik niet tussendoor...")


dialogId("ncp-m-barvy", "font_small", "I love colors...")
dialogStr("Ik hou van kleuren...")

==> fillets-ng-data_0.9.2.orig.tar.gz: fillets-ng-data-0.9.2/script/imprisoned/dialogs_nl.lua <==

dialogId("ncp-m-tesno0", "font_small", "Look, how I am supposed to get out of here?")
dialogStr("Kijk nou, hoe moet ik hier nou weer uit zien te komen?")


dialogId("ncp-m-tesno1", "font_small", "It’s quite tight in here.")
dialogStr("Beetje krap hier.")


dialogId("ncp-v-dostala", "font_big", "How did you manage to get there?")
dialogStr("Hoe kom je daar nou weer terecht?")


dialogId("ncp-v-sasanka", "font_big", "Stop playing with anemones and help me to get us out of here.")
dialogStr("Hou op met die anemonen te spelen en help me ons hieruit te krijgen.")


dialogId("ncp-m-nekoukej", "font_small", "Don’t be surprised.")
dialogStr("Schrik niet, zeepaardje.")


dialogId("ncp-m-komari", "font_small", "There are so many corals here...")
dialogStr("Er zijn hier zo veel koralen...")


dialogId("ncp-v-ceho", "font_big", "What?")
dialogStr("Wat?")


dialogId("ncp-m-koraly", "font_small", "So many corals. Are you deaf or what?")
dialogStr("Zo veel koralen. Ben je doof ofzo?")


dialogId("ncp-m-tvrdy", "font_small", "Oh my, this is a hard coral.")
dialogStr("O, dit is een hard stuk koraal.")


dialogId("ncp-v-mekky", "font_big", "Oh my, this is a soft coral.")
dialogStr("O jeetje, dit is een zacht stuk koraal.")


dialogId("ncp-v-tak", "font_big", "So!")
dialogStr("Zo!")


dialogId("ncp-m-muzes", "font_small", "Now you can get out, can’t you?")
dialogStr("Nu kun je eruit, of niet?")


dialogId("ncp-v-neprojedu", "font_big", "Hmm, I can’t get through here...")
dialogStr("Hmm, hier pas ik niet tussendoor...")


dialogId("ncp-m-barvy", "font_small", "I love colors...")
dialogStr("Ik hou van kleurtjes...")
